The ``rainflow`` module
#######################

.. automodule:: pylife.stress.rainflow



API Documentation
-----------------

Detectors
.........

.. toctree::
   :maxdepth: 1

   rainflow/threepointdetector
   rainflow/fourpointdetector
   rainflow/fkmdetector


Recorders
.........

.. toctree::
   :maxdepth: 1

   rainflow/loopvaluerecorder
   rainflow/fullrecorder
   rainflow/abstractrecorder


Utility functions
.................

.. autofunction:: pylife.stress.rainflow.find_turns



Compatibility
.............

.. automodule:: pylife.stress.rainflow.compat
